@@ -309,7 +309,7 @@ class Runtime:
                     raise TypeError(msg)
 
                 if collection in self.collections:
-                    msg = f"Multiple versions of '{collection}' were found installed, only the first one will be used, {self.collections[collection].version} ({self.collections[collection].path})."
+                    msg = f"Another version of '{collection}' {collection_info['version']} was found installed in {path}, only the first one will be used, {self.collections[collection].version} ({self.collections[collection].path})."
                     logging.warning(msg)
                 else:
                     self.collections[collection] = Collection(
@@ -395,7 +395,9 @@ class Runtime:
         env["ANSIBLE_VERBOSE_TO_STDERR"] = "True"
 
         if set_acp:
-            env["ANSIBLE_COLLECTIONS_PATH"] = ":".join(self.config.collections_paths)
+            env["ANSIBLE_COLLECTIONS_PATH"] = ":".join(
+                list(dict.fromkeys(self.config.collections_paths)),
+            )
 
         for _ in range(self.max_retries + 1 if retry else 1):
             result = run_func(
@@ -636,6 +638,7 @@ class Runtime:
         if required_collections is None:
             required_collections = {}
 
+        self._prepare_ansible_paths()
         # first one is standard for collection layout repos and the last two
         # are part of Tower specification
         # https://docs.ansible.com/ansible-tower/latest/html/userguide/projects.html#ansible-galaxy-support
@@ -646,8 +649,6 @@ class Runtime:
                 file_path = self.project_dir / req_file
             self.install_requirements(file_path, retry=retry, offline=offline)
 
-        self._prepare_ansible_paths()
-
         if not install_local:
             return
 
@@ -922,7 +923,8 @@ class Runtime:
             return
         orig_value = self.environ.get(varname, default)
         if orig_value:
-            value = [*value, *orig_value.split(":")]
+            # we just want to avoid repeating the same entries, but order is important
+            value = list(dict.fromkeys([*value, *orig_value.split(":")]))
         value_str = ":".join(value)
         if value_str != self.environ.get(varname, ""):
             self.environ[varname] = value_str
